@@ -24,7 +24,7 @@ const maxMemoryGI = 4 * 1024 * 1024 * 1024
 
 var (
 	targetVMName       = "myvm"
-	expectedDVName     = targetVMName + "-" + "123"
+	expectedDVName     = "d7bc458c04f4863b9e517c9b1661fbd34c02dc02"
 	filesystemOverhead = cdiv1.FilesystemOverhead{
 		Global: "0.0",
 	}
@@ -206,7 +206,7 @@ var _ = Describe("Test mapping virtual machine attributes", func() {
 		Expect(*clock.UTC.OffsetSeconds).To(BeEquivalentTo(3600))
 	})
 
-	It("should create UTC clock without offset", func() {
+	It("should create UTC clock with timezone by name", func() {
 		vm = createVM()
 		vm.SetTimeZone(ovirtsdk.NewTimeZoneBuilder().
 			Name("Etc/GMT").MustBuild())
@@ -214,9 +214,9 @@ var _ = Describe("Test mapping virtual machine attributes", func() {
 		vmSpec, _ = mapper.MapVM(&targetVMName, &kubevirtv1.VirtualMachine{})
 
 		clock := vmSpec.Spec.Template.Spec.Domain.Clock
-		Expect(clock.Timezone).To(BeNil())
-		Expect(clock.UTC).NotTo(BeNil())
-		Expect(clock.UTC.OffsetSeconds).To(BeNil())
+		Expect(clock.Timezone).NotTo(BeNil())
+		Expect(string(*clock.Timezone)).To(Equal("Etc/GMT"))
+		Expect(clock.UTC).To(BeNil())
 	})
 
 	It("should handle cluster default bios type", func() {
@@ -273,11 +273,6 @@ var _ = Describe("Test mapping virtual machine attributes", func() {
 		Expect(clock.UTC.OffsetSeconds).To(BeNil())
 	})
 
-	It("should map placement policy", func() {
-		evictionStrategy := vmSpec.Spec.Template.Spec.EvictionStrategy
-		Expect(string(*evictionStrategy)).ToNot(BeNil())
-	})
-
 	It("should map annotations", func() {
 		annotations := vmSpec.ObjectMeta.Annotations
 		Expect(annotations[mapper.AnnotationComment]).To(Equal(vm.MustComment()))
@@ -455,7 +450,7 @@ var _ = Describe("Test mapping disks", func() {
 
 		Expect(dv.Spec.PVC.Resources.Requests).To(HaveKey(corev1.ResourceStorage))
 		storageResource := dv.Spec.PVC.Resources.Requests[corev1.ResourceStorage]
-		Expect(storageResource.Value()).To(BeEquivalentTo(1136235008))
+		Expect(storageResource.Value()).To(BeEquivalentTo(1136234735))
 
 		Expect(dv.Spec.PVC.StorageClassName).To(Not(BeNil()))
 		Expect(*dv.Spec.PVC.StorageClassName).To(Equal("storageclassname"))
@@ -488,7 +483,7 @@ var _ = Describe("Test mapping disks", func() {
 
 		Expect(dv.Spec.PVC.Resources.Requests).To(HaveKey(corev1.ResourceStorage))
 		storageResource := dv.Spec.PVC.Resources.Requests[corev1.ResourceStorage]
-		Expect(storageResource.Value()).To(BeEquivalentTo(1136235008))
+		Expect(storageResource.Value()).To(BeEquivalentTo(1136234735))
 
 		Expect(dv.Spec.PVC.StorageClassName).To(Not(BeNil()))
 		Expect(*dv.Spec.PVC.StorageClassName).To(Equal(scName))
